"""
CrysPyEditor
======

"""
name = "cryspy_editor"
from cryspy_editor.main_window import main_w


if __name__ == "__main__":
    main_w()
